@@ -375,244 +375,245 @@ class EventCode(Enum):
     NEW_UNLOCKED_PERSONAL_SEASON_REWARDS = 370
     PERSONAL_SEASON_POINTS_GAINED = 371
     PERSONAL_SEASON_PAST_SEASON_DATA_EVENT = 372
-    EASY_ANTI_CHEAT_MESSAGE_TO_CLIENT = 373
-    MATCH_LOOT_CHEST_OPENING_START = 374
-    MATCH_LOOT_CHEST_OPENING_FINISHED = 375
-    MATCH_LOOT_CHEST_OPENING_CANCEL = 376
-    NOTIFY_CRYSTAL_MATCH_REWARD = 377
-    CRYSTAL_REALM_FEEDBACK = 378
-    NEW_LOCATION_MARKER = 379
-    NEW_TUTORIAL_BLOCKER = 380
-    NEW_TILE_SWITCH = 381
-    NEW_INFORMATION_PROVIDER = 382
-    NEW_DYNAMIC_GUILD_LOGO = 383
-    NEW_DECORATION = 384
-    TUTORIAL_UPDATE = 385
-    TRIGGER_HINT_BOX = 386
-    RANDOM_DUNGEON_POSITION_INFO = 387
-    NEW_LOOT_CHEST = 388
-    UPDATE_LOOT_CHEST = 389
-    LOOT_CHEST_OPENED = 390
-    UPDATE_LOOT_PROTECTED_BY_MOBS_WITH_MINIMAP_DISPLAY = 391
-    NEW_SHRINE = 392
-    UPDATE_SHRINE = 393
-    UPDATE_ROOM = 394
-    NEW_MIST_DUNGEON_ROOM_MOB_SOUL = 395
-    NEW_HELLGATE_SHRINE = 396
-    UPDATE_HELLGATE_SHRINE = 397
-    ACTIVATE_HELLGATE_EXIT = 398
-    MUTE_PLAYER_UPDATE = 399
-    SHOP_TILE_UPDATE = 400
-    SHOP_UPDATE = 401
-    ANTI_CHEAT_KICK = 402
-    BATTL_EYE_SERVER_MESSAGE = 403
-    UNLOCK_VANITY_UNLOCK = 404
-    AVATAR_UNLOCKED = 405
-    CUSTOMIZATION_CHANGED = 406
-    BASE_VAULT_INFO = 407
-    GUILD_VAULT_INFO = 408
-    BANK_VAULT_INFO = 409
-    RECOVERY_VAULT_PLAYER_INFO = 410
-    RECOVERY_VAULT_GUILD_INFO = 411
-    UPDATE_WARDROBE = 412
-    CASTLE_PHASE_CHANGED = 413
-    GUILD_ACCOUNT_LOG_EVENT = 414
-    NEW_HIDEOUT_OBJECT = 415
-    NEW_HIDEOUT_MANAGEMENT = 416
-    NEW_HIDEOUT_EXIT = 417
-    INIT_HIDEOUT_ATTACK_START = 418
-    INIT_HIDEOUT_ATTACK_CANCEL = 419
-    INIT_HIDEOUT_ATTACK_FINISHED = 420
-    HIDEOUT_MANAGEMENT_UPDATE = 421
-    HIDEOUT_UPGRADE_WITH_POWER_CRYSTAL_RESULT = 422
-    IP_CHANGED = 423
-    SMART_CLUSTER_QUEUE_UPDATE_INFO = 424
-    SMART_CLUSTER_QUEUE_ACTIVE_INFO = 425
-    SMART_CLUSTER_QUEUE_KICK_WARNING = 426
-    SMART_CLUSTER_QUEUE_INVITE = 427
-    RECEIVED_GVG_SEASON_POINTS = 428
-    TOWER_POWER_POINT_UPDATE = 429
-    OPEN_WORLD_ATTACK_SCHEDULE_START = 430
-    OPEN_WORLD_ATTACK_SCHEDULE_FINISHED = 431
-    OPEN_WORLD_ATTACK_SCHEDULE_CANCEL = 432
-    OPEN_WORLD_ATTACK_CONQUER_START = 433
-    OPEN_WORLD_ATTACK_CONQUER_FINISHED = 434
-    OPEN_WORLD_ATTACK_CONQUER_CANCEL = 435
-    OPEN_WORLD_ATTACK_CONQUER_STATUS = 436
-    OPEN_WORLD_ATTACK_START = 437
-    OPEN_WORLD_ATTACK_END = 438
-    NEW_RANDOM_RESOURCE_BLOCKER = 439
-    NEW_HOME_OBJECT = 440
-    HIDEOUT_OBJECT_UPDATE = 441
-    UPDATE_INFAMY = 442
-    MINIMAP_POSITION_MARKERS = 443
-    NEW_TUNNEL_EXIT = 444
-    CORRUPTED_DUNGEON_UPDATE = 445
-    CORRUPTED_DUNGEON_STATUS = 446
-    CORRUPTED_DUNGEON_INFAMY = 447
-    HELLGATE_RESTRICTED_AREA_UPDATE = 448
-    HELLGATE_INFAMY = 449
-    HELLGATE_STATUS = 450
-    HELLGATE_STATUS_UPDATE = 451
-    HELLGATE_SUSPENSE = 452
-    REPLACE_SPELL_SLOT_WITH_MULTI_SPELL = 453
-    NEW_CORRUPTED_SHRINE = 454
-    UPDATE_CORRUPTED_SHRINE = 455
-    CORRUPTED_SHRINE_USAGE_START = 456
-    CORRUPTED_SHRINE_USAGE_CANCEL = 457
-    EXIT_USED = 458
-    LINKED_TO_OBJECT = 459
-    LINK_TO_OBJECT_BROKEN = 460
-    ESTIMATED_MARKET_VALUE_UPDATE = 461
-    STUCK_CANCEL = 462
-    DUNGON_ESCAPE_READY = 463
-    FACTION_WARFARE_CLUSTER_STATE = 464
-    FACTION_WARFARE_HAS_UNCLAIMED_WEEKLY_REPORTS_EVENT = 465
-    SIMPLE_FEEDBACK = 466
-    SMART_CLUSTER_QUEUE_SKIP_CLUSTER_ERROR = 467
-    XIGN_CODE_EVENT = 468
-    BATCH_USE_ITEM_START = 469
-    BATCH_USE_ITEM_END = 470
-    RED_ZONE_EVENT_CLUSTER_STATUS = 471
-    RED_ZONE_PLAYER_NOTIFICATION = 472
-    RED_ZONE_WORLD_EVENT = 473
-    FACTION_WARFARE_STATS = 474
-    UPDATE_FACTION_BALANCE_FACTORS = 475
-    FACTION_ENLISTMENT_CHANGED = 476
-    UPDATE_FACTION_RANK = 477
-    FACTION_WARFARE_CAMPAIGN_REWARDS_UNLOCKED = 478
-    FEATURED_FEATURE_UPDATE = 479
-    NEW_CARRIABLE_OBJECT = 480
-    MINIMAP_CRYSTAL_POSITION_MARKER = 481
-    CARRIED_OBJECT_UPDATE = 482
-    PICKUP_CARRIABLE_OBJECT_START = 483
-    PICKUP_CARRIABLE_OBJECT_CANCEL = 484
-    PICKUP_CARRIABLE_OBJECT_FINISHED = 485
-    DO_SIMPLE_ACTION_START = 486
-    DO_SIMPLE_ACTION_CANCEL = 487
-    DO_SIMPLE_ACTION_FINISHED = 488
-    NOTIFY_GUEST_ACCOUNT_VERIFIED = 489
-    MIGHT_AND_FAVOR_RECEIVED_EVENT = 490
-    WEEKLY_PVP_CHALLENGE_REWARD_STATE_UPDATE = 491
-    NEW_UNLOCKED_PVP_SEASON_CHALLENGE_REWARDS = 492
-    STATIC_DUNGEON_ENTRANCES_DUNGEON_EVENT_STATUS_UPDATES = 493
-    STATIC_DUNGEON_DUNGEON_VALUE_UPDATE = 494
-    STATIC_DUNGEON_ENTRANCE_DUNGEON_EVENTS_ABORTED = 495
-    IN_APP_PURCHASE_CONFIRMED_GOOGLE_PLAY = 496
-    FEATURE_SWITCH_INFO = 497
-    PARTY_JOIN_REQUEST_ABORTED = 498
-    PARTY_INVITE_ABORTED = 499
-    PARTY_START_HUNT_REQUEST = 500
-    PARTY_START_HUNT_REQUESTED = 501
-    PARTY_START_HUNT_REQUEST_ANSWER = 502
-    PARTY_PLAYER_LEAVE_SCHEDULED = 503
-    GUILD_INVITE_DECLINED = 504
-    CANCEL_MULTI_SPELL_SLOTS = 505
-    NEW_VISUAL_EVENT_OBJECT = 506
-    CASTLE_CLAIM_PROGRESS = 507
-    CASTLE_CLAIM_PROGRESS_LOGO = 508
-    TOWN_PORTAL_UPDATE_STATE = 509
-    TOWN_PORTAL_FAILED = 510
-    CONSUMABLE_VANITY_CHARGES_ADDED = 511
-    FESTIVITIES_UPDATE = 512
-    NEW_BANNER_OBJECT = 513
-    NEW_MISTS_IMMEDIATE_RETURN_EXIT = 514
-    MISTS_PLAYER_JOINED_INFO = 515
-    NEW_MISTS_STATIC_ENTRANCE = 516
-    NEW_MISTS_OPEN_WORLD_EXIT = 517
-    NEW_TUNNEL_EXIT_TEMP = 518
-    NEW_MISTS_WISP_SPAWN = 519
-    MISTS_WISP_SPAWN_STATE_CHANGE = 520
-    NEW_MISTS_CITY_ENTRANCE = 521
-    NEW_MISTS_CITY_ROADS_ENTRANCE = 522
-    MISTS_CITY_ROADS_ENTRANCE_PARTY_STATE_UPDATE = 523
-    MISTS_CITY_ROADS_ENTRANCE_CLEAR_STATE_FOR_PARTY = 524
-    MISTS_ENTRANCE_DATA_CHANGED = 525
-    NEW_CAGED_OBJECT = 526
-    CAGED_OBJECT_STATE_UPDATED = 527
-    MISTS_ENTRANCE_PARTY_BINDING_CREATED = 528
-    MISTS_ENTRANCE_PARTY_BINDING_CLEARED = 529
-    MISTS_ENTRANCE_PARTY_BINDING_INFOS = 530
-    NEW_MISTS_BORDER_EXIT = 531
-    NEW_MISTS_DUNGEON_EXIT = 532
-    LOCAL_QUEST_INFOS = 533
-    LOCAL_QUEST_STARTED = 534
-    LOCAL_QUEST_ACTIVE = 535
-    LOCAL_QUEST_INACTIVE = 536
-    LOCAL_QUEST_PROGRESS_UPDATE = 537
-    NEW_UNRESTRICTED_PVP_ZONE = 538
-    TEMPORARY_FLAGGING_STATUS_UPDATE = 539
-    SPELL_TEST_PERFORMANCE_UPDATE = 540
-    TRANSFORMATION = 541
-    TRANSFORMATION_END = 542
-    UPDATE_TRUSTLEVEL = 543
-    REVEAL_HIDDEN_TIME_STAMPS = 544
-    MODIFY_ITEM_TRAIT_FINISHED = 545
-    REROLL_ITEM_TRAIT_VALUE_FINISHED = 546
-    HUNT_QUEST_PROGRESS_INFO = 547
-    HUNT_STARTED = 548
-    HUNT_FINISHED = 549
-    HUNT_ABORTED = 550
-    HUNT_MISSION_STEP_STATE_UPDATE = 551
-    NEW_HUNT_TRACK = 552
-    HUNT_MISSION_UPDATE = 553
-    HUNT_QUEST_MISSION_PROGRESS_UPDATE = 554
-    HUNT_TRACK_USED = 555
-    HUNT_TRACK_USEABLE_AGAIN = 556
-    MINIMAP_HUNT_TRACK_MARKERS = 557
-    NO_TRACKS_FOUND = 558
-    HUNT_QUEST_ABORTED = 559
-    INTERACT_WITH_TRACK_START = 560
-    INTERACT_WITH_TRACK_CANCEL = 561
-    INTERACT_WITH_TRACK_FINISHED = 562
-    NEW_DYNAMIC_COMPOUND = 563
-    LEGENDARY_ITEM_DESTROYED = 564
-    ATTUNEMENT_INFO = 565
-    TERRITORY_CLAIM_RAIDED_RAW_ENERGY_CRYSTAL_RESULT = 566
-    CARRIED_OBJECT_EXPIRY_WARNING = 567
-    CARRIED_OBJECT_EXPIRED = 568
-    TERRITORY_RAID_START = 569
-    TERRITORY_RAID_CANCEL = 570
-    TERRITORY_RAID_FINISHED = 571
-    TERRITORY_RAID_RESULT = 572
-    TERRITORY_MONOLITH_ACTIVE_RAID_STATUS = 573
-    TERRITORY_MONOLITH_ACTIVE_RAID_CANCELLED = 574
-    MONOLITH_ENERGY_STORAGE_UPDATE = 575
-    MONOLITH_NEXT_SCHEDULED_OPEN_WORLD_ATTACK_UPDATE = 576
-    MONOLITH_PROTECTED_BUILDINGS_DAMAGE_REDUCTION_UPDATE = 577
-    NEW_BUILDING_BASE_EVENT = 578
-    NEW_FORTIFICATION_BUILDING = 579
-    NEW_CASTLE_GATE_BUILDING = 580
-    BUILDING_DURABILITY_UPDATE = 581
-    MONOLITH_FORTIFICATION_POINTS_UPDATE = 582
-    FORTIFICATION_BUILDING_UPGRADE_INFO = 583
-    FORTIFICATION_BUILDINGS_DAMAGE_STATE_UPDATE = 584
-    SIEGE_NOTIFICATION_EVENT = 585
-    UPDATE_ENEMY_WAR_BANNER_ACTIVE = 586
-    TERRITORY_ANNOUNCE_PLAYER_EJECTION = 587
-    CASTLE_GATE_SWITCH_USE_STARTED = 588
-    CASTLE_GATE_SWITCH_USE_FINISHED = 589
-    FORTIFICATION_BUILDING_WILL_DOWNGRADE = 590
-    BOT_COMMAND = 591
-    JOURNAL_ACHIEVEMENT_PROGRESS_UPDATE = 592
-    JOURNAL_CLAIMABLE_REWARD_UPDATE = 593
-    KEY_SYNC = 594
-    LOCAL_QUEST_AREA_GONE = 595
-    DYNAMIC_TEMPLATE = 596
-    DYNAMIC_TEMPLATE_FORCED_STATE_CHANGE = 597
-    NEW_OUTLANDS_TELEPORTATION_PORTAL = 598
-    NEW_OUTLANDS_TELEPORTATION_RETURN_PORTAL = 599
-    OUTLANDS_TELEPORTATION_BINDING_CLEARED = 600
-    OUTLANDS_TELEPORTATION_RETURN_PORTAL_UPDATE_EVENT = 601
-    PLAYER_USED_OUTLANDS_TELEPORTATION_PORTAL = 602
-    ENCUMBERED_RESTRICTED = 603
-    NEW_PILED_OBJECT = 604
-    PILED_OBJECT_STATE_CHANGED = 605
-    NEW_SMUGGLER_CRATE_DELIVERY_STATION = 606
-    KILL_REWARDED_NO_FAME = 607
-    PICKUP_FROM_PILED_OBJECT_START = 608
-    PICKUP_FROM_PILED_OBJECT_CANCEL = 609
-    PICKUP_FROM_PILED_OBJECT_RESET = 610
-    PICKUP_FROM_PILED_OBJECT_FINISHED = 611
-    ARMORY_ACTIVITY_CHANGE = 612
-    NEW_KILL_TROPHY_FURNITURE_BUILDING = 61
+    MATCH_LOOT_CHEST_OPENING_START = 373
+    MATCH_LOOT_CHEST_OPENING_FINISHED = 374
+    MATCH_LOOT_CHEST_OPENING_CANCEL = 375
+    NOTIFY_CRYSTAL_MATCH_REWARD = 376
+    CRYSTAL_REALM_FEEDBACK = 377
+    NEW_LOCATION_MARKER = 378
+    NEW_TUTORIAL_BLOCKER = 379
+    NEW_TILE_SWITCH = 380
+    NEW_INFORMATION_PROVIDER = 381
+    NEW_DYNAMIC_GUILD_LOGO = 382
+    NEW_DECORATION = 383
+    TUTORIAL_UPDATE = 384
+    TRIGGER_HINT_BOX = 385
+    RANDOM_DUNGEON_POSITION_INFO = 386
+    NEW_LOOT_CHEST = 387
+    UPDATE_LOOT_CHEST = 388
+    LOOT_CHEST_OPENED = 389
+    UPDATE_LOOT_PROTECTED_BY_MOBS_WITH_MINIMAP_DISPLAY = 390
+    NEW_SHRINE = 391
+    UPDATE_SHRINE = 392
+    UPDATE_ROOM = 393
+    NEW_MIST_DUNGEON_ROOM_MOB_SOUL = 394
+    NEW_HELLGATE_SHRINE = 395
+    UPDATE_HELLGATE_SHRINE = 396
+    ACTIVATE_HELLGATE_EXIT = 397
+    MUTE_PLAYER_UPDATE = 398
+    SHOP_TILE_UPDATE = 399
+    SHOP_UPDATE = 400
+    ANTI_CHEAT_KICK = 401
+    BATTL_EYE_SERVER_MESSAGE = 402
+    UNLOCK_VANITY_UNLOCK = 403
+    AVATAR_UNLOCKED = 404
+    CUSTOMIZATION_CHANGED = 405
+    BASE_VAULT_INFO = 406
+    GUILD_VAULT_INFO = 407
+    BANK_VAULT_INFO = 408
+    RECOVERY_VAULT_PLAYER_INFO = 409
+    RECOVERY_VAULT_GUILD_INFO = 410
+    UPDATE_WARDROBE = 411
+    CASTLE_PHASE_CHANGED = 412
+    GUILD_ACCOUNT_LOG_EVENT = 413
+    NEW_HIDEOUT_OBJECT = 414
+    NEW_HIDEOUT_MANAGEMENT = 415
+    NEW_HIDEOUT_EXIT = 416
+    INIT_HIDEOUT_ATTACK_START = 417
+    INIT_HIDEOUT_ATTACK_CANCEL = 418
+    INIT_HIDEOUT_ATTACK_FINISHED = 419
+    HIDEOUT_MANAGEMENT_UPDATE = 420
+    HIDEOUT_UPGRADE_WITH_POWER_CRYSTAL_RESULT = 421
+    IP_CHANGED = 422
+    SMART_CLUSTER_QUEUE_UPDATE_INFO = 423
+    SMART_CLUSTER_QUEUE_ACTIVE_INFO = 424
+    SMART_CLUSTER_QUEUE_KICK_WARNING = 425
+    SMART_CLUSTER_QUEUE_INVITE = 426
+    RECEIVED_GVG_SEASON_POINTS = 427
+    TOWER_POWER_POINT_UPDATE = 428
+    OPEN_WORLD_ATTACK_SCHEDULE_START = 429
+    OPEN_WORLD_ATTACK_SCHEDULE_FINISHED = 430
+    OPEN_WORLD_ATTACK_SCHEDULE_CANCEL = 431
+    OPEN_WORLD_ATTACK_CONQUER_START = 432
+    OPEN_WORLD_ATTACK_CONQUER_FINISHED = 433
+    OPEN_WORLD_ATTACK_CONQUER_CANCEL = 434
+    OPEN_WORLD_ATTACK_CONQUER_STATUS = 435
+    OPEN_WORLD_ATTACK_START = 436
+    OPEN_WORLD_ATTACK_END = 437
+    NEW_RANDOM_RESOURCE_BLOCKER = 438
+    NEW_HOME_OBJECT = 439
+    HIDEOUT_OBJECT_UPDATE = 440
+    UPDATE_INFAMY = 441
+    MINIMAP_POSITION_MARKERS = 442
+    NEW_TUNNEL_EXIT = 443
+    CORRUPTED_DUNGEON_UPDATE = 444
+    CORRUPTED_DUNGEON_STATUS = 445
+    CORRUPTED_DUNGEON_INFAMY = 446
+    HELLGATE_RESTRICTED_AREA_UPDATE = 447
+    HELLGATE_INFAMY = 448
+    HELLGATE_STATUS = 449
+    HELLGATE_STATUS_UPDATE = 450
+    HELLGATE_SUSPENSE = 451
+    REPLACE_SPELL_SLOT_WITH_MULTI_SPELL = 452
+    NEW_CORRUPTED_SHRINE = 453
+    UPDATE_CORRUPTED_SHRINE = 454
+    CORRUPTED_SHRINE_USAGE_START = 455
+    CORRUPTED_SHRINE_USAGE_CANCEL = 456
+    EXIT_USED = 457
+    LINKED_TO_OBJECT = 458
+    LINK_TO_OBJECT_BROKEN = 459
+    ESTIMATED_MARKET_VALUE_UPDATE = 460
+    STUCK_CANCEL = 461
+    DUNGON_ESCAPE_READY = 462
+    FACTION_WARFARE_CLUSTER_STATE = 463
+    FACTION_WARFARE_HAS_UNCLAIMED_WEEKLY_REPORTS_EVENT = 464
+    SIMPLE_FEEDBACK = 465
+    SMART_CLUSTER_QUEUE_SKIP_CLUSTER_ERROR = 466
+    XIGN_CODE_EVENT = 467
+    BATCH_USE_ITEM_START = 468
+    BATCH_USE_ITEM_END = 469
+    RED_ZONE_EVENT_CLUSTER_STATUS = 470
+    RED_ZONE_PLAYER_NOTIFICATION = 471
+    RED_ZONE_WORLD_EVENT = 472
+    FACTION_WARFARE_STATS = 473
+    UPDATE_FACTION_BALANCE_FACTORS = 474
+    FACTION_ENLISTMENT_CHANGED = 475
+    UPDATE_FACTION_RANK = 476
+    FACTION_WARFARE_CAMPAIGN_REWARDS_UNLOCKED = 477
+    FEATURED_FEATURE_UPDATE = 478
+    NEW_CARRIABLE_OBJECT = 479
+    MINIMAP_CRYSTAL_POSITION_MARKER = 480
+    CARRIED_OBJECT_UPDATE = 481
+    PICKUP_CARRIABLE_OBJECT_START = 482
+    PICKUP_CARRIABLE_OBJECT_CANCEL = 483
+    PICKUP_CARRIABLE_OBJECT_FINISHED = 484
+    DO_SIMPLE_ACTION_START = 485
+    DO_SIMPLE_ACTION_CANCEL = 486
+    DO_SIMPLE_ACTION_FINISHED = 487
+    NOTIFY_GUEST_ACCOUNT_VERIFIED = 488
+    MIGHT_AND_FAVOR_RECEIVED_EVENT = 489
+    WEEKLY_PVP_CHALLENGE_REWARD_STATE_UPDATE = 490
+    NEW_UNLOCKED_PVP_SEASON_CHALLENGE_REWARDS = 491
+    STATIC_DUNGEON_ENTRANCES_DUNGEON_EVENT_STATUS_UPDATES = 492
+    STATIC_DUNGEON_DUNGEON_VALUE_UPDATE = 493
+    STATIC_DUNGEON_ENTRANCE_DUNGEON_EVENTS_ABORTED = 494
+    IN_APP_PURCHASE_CONFIRMED_GOOGLE_PLAY = 495
+    FEATURE_SWITCH_INFO = 496
+    PARTY_JOIN_REQUEST_ABORTED = 497
+    PARTY_INVITE_ABORTED = 498
+    PARTY_START_HUNT_REQUEST = 499
+    PARTY_START_HUNT_REQUESTED = 500
+    PARTY_START_HUNT_REQUEST_ANSWER = 501
+    PARTY_PLAYER_LEAVE_SCHEDULED = 502
+    GUILD_INVITE_DECLINED = 503
+    CANCEL_MULTI_SPELL_SLOTS = 504
+    NEW_VISUAL_EVENT_OBJECT = 505
+    CASTLE_CLAIM_PROGRESS = 506
+    CASTLE_CLAIM_PROGRESS_LOGO = 507
+    TOWN_PORTAL_UPDATE_STATE = 508
+    TOWN_PORTAL_FAILED = 509
+    CONSUMABLE_VANITY_CHARGES_ADDED = 510
+    FESTIVITIES_UPDATE = 511
+    NEW_BANNER_OBJECT = 512
+    NEW_MISTS_IMMEDIATE_RETURN_EXIT = 513
+    MISTS_PLAYER_JOINED_INFO = 514
+    NEW_MISTS_STATIC_ENTRANCE = 515
+    NEW_MISTS_OPEN_WORLD_EXIT = 516
+    NEW_TUNNEL_EXIT_TEMP = 517
+    NEW_MISTS_WISP_SPAWN = 518
+    MISTS_WISP_SPAWN_STATE_CHANGE = 519
+    NEW_MISTS_CITY_ENTRANCE = 520
+    NEW_MISTS_CITY_ROADS_ENTRANCE = 521
+    MISTS_CITY_ROADS_ENTRANCE_PARTY_STATE_UPDATE = 522
+    MISTS_CITY_ROADS_ENTRANCE_CLEAR_STATE_FOR_PARTY = 523
+    MISTS_ENTRANCE_DATA_CHANGED = 524
+    NEW_CAGED_OBJECT = 525
+    CAGED_OBJECT_STATE_UPDATED = 526
+    MISTS_ENTRANCE_PARTY_BINDING_CREATED = 527
+    MISTS_ENTRANCE_PARTY_BINDING_CLEARED = 528
+    MISTS_ENTRANCE_PARTY_BINDING_INFOS = 529
+    NEW_MISTS_BORDER_EXIT = 530
+    NEW_MISTS_DUNGEON_EXIT = 531
+    LOCAL_QUEST_INFOS = 532
+    LOCAL_QUEST_STARTED = 533
+    LOCAL_QUEST_ACTIVE = 534
+    LOCAL_QUEST_INACTIVE = 535
+    LOCAL_QUEST_PROGRESS_UPDATE = 536
+    NEW_UNRESTRICTED_PVP_ZONE = 537
+    TEMPORARY_FLAGGING_STATUS_UPDATE = 538
+    SPELL_TEST_PERFORMANCE_UPDATE = 539
+    TRANSFORMATION = 540
+    TRANSFORMATION_END = 541
+    UPDATE_TRUSTLEVEL = 542
+    REVEAL_HIDDEN_TIME_STAMPS = 543
+    MODIFY_ITEM_TRAIT_FINISHED = 544
+    REROLL_ITEM_TRAIT_VALUE_FINISHED = 545
+    HUNT_QUEST_PROGRESS_INFO = 546
+    HUNT_STARTED = 547
+    HUNT_FINISHED = 548
+    HUNT_ABORTED = 549
+    HUNT_MISSION_STEP_STATE_UPDATE = 550
+    NEW_HUNT_TRACK = 551
+    HUNT_MISSION_UPDATE = 552
+    HUNT_QUEST_MISSION_PROGRESS_UPDATE = 553
+    HUNT_TRACK_USED = 554
+    HUNT_TRACK_USEABLE_AGAIN = 555
+    MINIMAP_HUNT_TRACK_MARKERS = 556
+    NO_TRACKS_FOUND = 557
+    HUNT_QUEST_ABORTED = 558
+    INTERACT_WITH_TRACK_START = 559
+    INTERACT_WITH_TRACK_CANCEL = 560
+    INTERACT_WITH_TRACK_FINISHED = 561
+    NEW_DYNAMIC_COMPOUND = 562
+    LEGENDARY_ITEM_DESTROYED = 563
+    ATTUNEMENT_INFO = 564
+    TERRITORY_CLAIM_RAIDED_RAW_ENERGY_CRYSTAL_RESULT = 565
+    CARRIED_OBJECT_EXPIRY_WARNING = 566
+    CARRIED_OBJECT_EXPIRED = 567
+    TERRITORY_RAID_START = 568
+    TERRITORY_RAID_CANCEL = 569
+    TERRITORY_RAID_FINISHED = 570
+    TERRITORY_RAID_RESULT = 571
+    TERRITORY_MONOLITH_ACTIVE_RAID_STATUS = 572
+    TERRITORY_MONOLITH_ACTIVE_RAID_CANCELLED = 573
+    MONOLITH_ENERGY_STORAGE_UPDATE = 574
+    MONOLITH_NEXT_SCHEDULED_OPEN_WORLD_ATTACK_UPDATE = 575
+    MONOLITH_PROTECTED_BUILDINGS_DAMAGE_REDUCTION_UPDATE = 576
+    NEW_BUILDING_BASE_EVENT = 577
+    NEW_FORTIFICATION_BUILDING = 578
+    NEW_CASTLE_GATE_BUILDING = 579
+    BUILDING_DURABILITY_UPDATE = 580
+    MONOLITH_FORTIFICATION_POINTS_UPDATE = 581
+    FORTIFICATION_BUILDING_UPGRADE_INFO = 582
+    FORTIFICATION_BUILDINGS_DAMAGE_STATE_UPDATE = 583
+    SIEGE_NOTIFICATION_EVENT = 584
+    UPDATE_ENEMY_WAR_BANNER_ACTIVE = 585
+    TERRITORY_ANNOUNCE_PLAYER_EJECTION = 586
+    CASTLE_GATE_SWITCH_USE_STARTED = 587
+    CASTLE_GATE_SWITCH_USE_FINISHED = 588
+    FORTIFICATION_BUILDING_WILL_DOWNGRADE = 589
+    BOT_COMMAND = 590
+    JOURNAL_ACHIEVEMENT_PROGRESS_UPDATE = 591
+    JOURNAL_CLAIMABLE_REWARD_UPDATE = 592
+    KEY_SYNC = 593
+    LOCAL_QUEST_AREA_GONE = 594
+    DYNAMIC_TEMPLATE = 595
+    DYNAMIC_TEMPLATE_FORCED_STATE_CHANGE = 596
+    NEW_OUTLANDS_TELEPORTATION_PORTAL = 597
+    NEW_OUTLANDS_TELEPORTATION_RETURN_PORTAL = 598
+    OUTLANDS_TELEPORTATION_BINDING_CLEARED = 599
+    OUTLANDS_TELEPORTATION_RETURN_PORTAL_UPDATE_EVENT = 600
+    PLAYER_USED_OUTLANDS_TELEPORTATION_PORTAL = 601
+    ENCUMBERED_RESTRICTED = 602
+    NEW_PILED_OBJECT = 603
+    PILED_OBJECT_STATE_CHANGED = 604
+    NEW_SMUGGLER_CRATE_DELIVERY_STATION = 605
+    KILL_REWARDED_NO_FAME = 606
+    PICKUP_FROM_PILED_OBJECT_START = 607
+    PICKUP_FROM_PILED_OBJECT_CANCEL = 608
+    PICKUP_FROM_PILED_OBJECT_RESET = 609
+    PICKUP_FROM_PILED_OBJECT_FINISHED = 610
+    ARMORY_ACTIVITY_CHANGE = 611
+    NEW_KILL_TROPHY_FURNITURE_BUILDING = 612
+    STAND_TIME_FINISHED = 613
+    EPIC_ACHIEVEMENT_AND_STATS_UPDATE = 61
