@@ -2,6 +2,7 @@ from enum import Enum
 
 
 class OperationCode(Enum):
+
     UNUSED = 0
     PING = 1
     JOIN = 2
@@ -338,178 +339,183 @@ class OperationCode(Enum):
     STEAM_ID_HAS_ACTIVE_ACCOUNT = 333
     CHECK_EMAIL_ACCOUNT_STATE = 334
     LINK_ACCOUNT_TO_STEAM_ID = 335
-    IN_APP_CONFIRM_PAYMENT_GOOGLE_PLAY = 336
-    IN_APP_CONFIRM_PAYMENT_APPLE_APP_STORE = 337
-    IN_APP_PURCHASE_REQUEST = 338
-    IN_APP_PURCHASE_FAILED = 339
-    CHARACTER_SUBSCRIPTION_INFO = 340
-    ACCOUNT_SUBSCRIPTION_INFO = 341
-    BUY_GVG_SEASON_BOOSTER = 342
-    CHANGE_FLAGGING_PREPARE = 343
-    OVER_CHARGE = 344
-    OVER_CHARGE_END = 345
-    REQUEST_TRUSTED = 346
-    CHANGE_GUILD_LOGO = 347
-    PARTY_FINDER_REGISTER_FOR_UPDATES = 348
-    PARTY_FINDER_UNREGISTER_FOR_UPDATES = 349
-    PARTY_FINDER_ENLIST_NEW_PARTY_SEARCH = 350
-    PARTY_FINDER_DELETE_PARTY_SEARCH = 351
-    PARTY_FINDER_CHANGE_PARTY_SEARCH = 352
-    PARTY_FINDER_CHANGE_ROLE = 353
-    PARTY_FINDER_APPLY_FOR_GROUP = 354
-    PARTY_FINDER_ACCEPT_OR_DECLINE_APPLY_FOR_GROUP = 355
-    PARTY_FINDER_GET_EQUIPMENT_SNAPSHOT = 356
-    PARTY_FINDER_REGISTER_APPLICANTS = 357
-    PARTY_FINDER_UNREGISTER_APPLICANTS = 358
-    PARTY_FINDER_FULLTEXT_SEARCH = 359
-    PARTY_FINDER_REQUEST_EQUIPMENT_SNAPSHOT = 360
-    GET_PERSONAL_SEASON_TRACKER_DATA = 361
-    GET_PERSONAL_SEASON_PAST_REWARD_DATA = 362
-    USE_CONSUMABLE_FROM_INVENTORY = 363
-    CLAIM_PERSONAL_SEASON_REWARD = 364
-    EASY_ANTI_CHEAT_MESSAGE_TO_SERVER = 365
-    XIGN_CODE_MESSAGE_TO_SERVER = 366
-    BATTL_EYE_MESSAGE_TO_SERVER = 367
-    SET_NEXT_TUTORIAL_STATE = 368
-    ADD_PLAYER_TO_MUTE_LIST = 369
-    REMOVE_PLAYER_FROM_MUTE_LIST = 370
-    PRODUCT_SHOP_USER_EVENT = 371
-    GET_VANITY_UNLOCKS = 372
-    BUY_VANITY_UNLOCKS = 373
-    GET_MOUNT_SKINS = 374
-    SET_MOUNT_SKIN = 375
-    SET_WARDROBE = 376
-    CHANGE_CUSTOMIZATION = 377
-    CHANGE_PLAYER_ISLAND_DATA = 378
-    GET_GUILD_CHALLENGE_POINTS = 379
-    SMART_QUEUE_JOIN = 380
-    SMART_QUEUE_LEAVE = 381
-    SMART_QUEUE_SELECT_SPAWN_CLUSTER = 382
-    UPGRADE_HIDEOUT = 383
-    INIT_HIDEOUT_ATTACK_START = 384
-    INIT_HIDEOUT_ATTACK_CANCEL = 385
-    HIDEOUT_FILL_NUTRITION = 386
-    HIDEOUT_GET_INFO = 387
-    HIDEOUT_GET_OWNER_INFO = 388
-    HIDEOUT_SET_TRIBUTE = 389
-    HIDEOUT_UPGRADE_WITH_POWER_CRYSTAL = 390
-    HIDEOUT_DECLARE_H_Q = 391
-    HIDEOUT_UNDECLARE_H_Q = 392
-    HIDEOUT_GET_H_Q_REQUIREMENTS = 393
-    HIDEOUT_BOOST = 394
-    HIDEOUT_BOOST_CONSTRUCTION = 395
-    OPEN_WORLD_ATTACK_SCHEDULE_START = 396
-    OPEN_WORLD_ATTACK_SCHEDULE_CANCEL = 397
-    OPEN_WORLD_ATTACK_CONQUER_START = 398
-    OPEN_WORLD_ATTACK_CONQUER_CANCEL = 399
-    GET_OPEN_WORLD_ATTACK_DETAILS = 400
-    GET_NEXT_OPEN_WORLD_ATTACK_SCHEDULE_TIME = 401
-    RECOVER_VAULT_FROM_HIDEOUT = 402
-    GET_GUILD_ENERGY_DRAIN_INFO = 403
-    CHANNELING_UPDATE = 404
-    USE_CORRUPTED_SHRINE = 405
-    REQUEST_ESTIMATED_MARKET_VALUE = 406
-    LOG_FEEDBACK = 407
-    GET_INFAMY_INFO = 408
-    GET_PARTY_SMART_CLUSTER_QUEUE_PRIORITY = 409
-    SET_PARTY_SMART_CLUSTER_QUEUE_PRIORITY = 410
-    CLIENT_ANTI_AUTO_CLICKER_INFO = 411
-    CLIENT_BOT_PATTERN_DETECTION_INFO = 412
-    CLIENT_ANTI_GATHER_CLICKER_INFO = 413
-    LOADOUT_CREATE = 414
-    LOADOUT_READ = 415
-    LOADOUT_READ_HEADERS = 416
-    LOADOUT_UPDATE = 417
-    LOADOUT_DELETE = 418
-    LOADOUT_ORDER_UPDATE = 419
-    LOADOUT_EQUIP = 420
-    BATCH_USE_ITEM_CANCEL = 421
-    ENLIST_FACTION_WARFARE = 422
-    GET_FACTION_WARFARE_WEEKLY_REPORT = 423
-    CLAIM_FACTION_WARFARE_WEEKLY_REPORT = 424
-    GET_FACTION_WARFARE_CAMPAIGN_DATA = 425
-    CLAIM_FACTION_WARFARE_ITEM_REWARD = 426
-    SEND_MEMORY_CONSUMPTION = 427
-    PICKUP_CARRIABLE_OBJECT_START = 428
-    PICKUP_CARRIABLE_OBJECT_CANCEL = 429
-    SET_SAVING_CHEST_LOGS_FLAG = 430
-    GET_SAVING_CHEST_LOGS_FLAG = 431
-    REGISTER_GUEST_ACCOUNT = 432
-    RESEND_GUEST_ACCOUNT_VERIFICATION_EMAIL = 433
-    DO_SIMPLE_ACTION_START = 434
-    DO_SIMPLE_ACTION_CANCEL = 435
-    GET_GVG_SEASON_CONTRIBUTION_BY_ACTIVITY = 436
-    GET_GVG_SEASON_CONTRIBUTION_BY_CRYSTAL_LEAGUE = 437
-    GET_GUILD_MIGHT_CATEGORY_CONTRIBUTION = 438
-    GET_GUILD_MIGHT_CATEGORY_OVERVIEW = 439
-    GET_PVP_CHALLENGE_DATA = 440
-    CLAIM_PVP_CHALLENGE_WEEKLY_REWARD = 441
-    GET_PERSONAL_MIGHT_STATS = 442
-    AUCTION_GET_LOADOUT_OFFERS = 443
-    AUCTION_BUY_LOADOUT_OFFER = 444
-    ACCOUNT_DELETION_REQUEST = 445
-    ACCOUNT_REACTIVATION_REQUEST = 446
-    GET_MODERATION_ESCALATION_DEFINITON = 447
-    EVENT_BASED_POPUP_ADD_SEEN = 448
-    GET_ITEM_KILL_HISTORY = 449
-    GET_VANITY_CONSUMABLES = 450
-    EQUIP_KILL_EMOTE = 451
-    CHANGE_KILL_EMOTE_PLAY_ON_KNOCKDOWN_SETTING = 452
-    BUY_VANITY_CONSUMABLE_CHARGES = 453
-    RECLAIM_VANITY_ITEM = 454
-    GET_ARENA_RANKINGS = 455
-    GET_CRYSTAL_LEAGUE_STATISTICS = 456
-    SEND_OPTIONS_LOG = 457
-    SEND_CONTROLS_OPTIONS_LOG = 458
-    MISTS_USE_IMMEDIATE_RETURN_EXIT = 459
-    MISTS_USE_STATIC_ENTRANCE = 460
-    MISTS_USE_CITY_ROADS_ENTRANCE = 461
-    CHANGE_NEW_GUILD_MEMBER_MAIL = 462
-    GET_NEW_GUILD_MEMBER_MAIL = 463
-    CHANGE_GUILD_FACTION_ALLEGIANCE = 464
-    GET_GUILD_FACTION_ALLEGIANCE = 465
-    GUILD_BANNER_CHANGE = 466
-    GUILD_GET_OPTIONAL_STATS = 467
-    GUILD_SET_OPTIONAL_STATS = 468
-    GET_PLAYER_INFO_FOR_STALK = 469
-    PAY_GOLD_FOR_CHARACTER_TYPE_CHANGE = 470
-    QUICK_SELL_AUCTION_QUERY_ACTION = 471
-    QUICK_SELL_AUCTION_SELL_ACTION = 472
-    FCM_TOKEN_TO_SERVER = 473
-    APNS_TOKEN_TO_SERVER = 474
-    DEATH_RECAP = 475
-    AUCTION_FETCH_FINISHED_AUCTIONS = 476
-    ABORT_AUCTION_FETCH_FINISHED_AUCTIONS = 477
-    REQUEST_LEGENDARY_EVEN_HISTORY = 478
-    PARTY_ANSWER_START_HUNT_REQUEST = 479
-    HUNT_ABORT = 480
-    USE_FIND_TRACK_SPELL_FROM_ITEM_PREPARE = 481
-    INTERACT_WITH_TRACK_START = 482
-    INTERACT_WITH_TRACK_CANCEL = 483
-    TERRITORY_RAID_START = 484
-    TERRITORY_RAID_CANCEL = 485
-    TERRITORY_CLAIM_RAIDED_RAW_ENERGY_CRYSTAL_RESULT = 486
-    GV_G_SEASON_PLAYER_GUILD_PARTICIPATION_DETAILS = 487
-    DAILY_MIGHT_BONUS = 488
-    CLAIM_DAILY_MIGHT_BONUS = 489
-    GET_FORTIFICATION_GROUP_INFO = 490
-    UPGRADE_FORTIFICATION_GROUP = 491
-    CANCEL_UPGRADE_FORTIFICATION_GROUP = 492
-    DOWNGRADE_FORTIFICATION_GROUP = 493
-    GET_CLUSTER_ACTIVITY_CHEST_ESTIMATES = 494
-    PARTY_READY_CHECK_BEGIN = 495
-    PARTY_READY_CHECK_UPDATE = 496
-    CLAIM_ALBION_JOURNAL_REWARD = 497
-    TRACK_ALBION_JOURNAL_ACHIEVEMENTS = 498
-    REQUEST_OUTLANDS_TELEPORTATION_USAGE = 499
-    PICKUP_FROM_PILED_OBJECT_START = 500
-    PICKUP_FROM_PILED_OBJECT_CANCEL = 501
-    ASSET_OVERVIEW = 502
-    ASSET_OVERVIEW_TABS = 503
-    ASSET_OVERVIEW_TAB_CONTENT = 504
-    ASSET_OVERVIEW_UNFREEZE_CACHE = 505
-    ASSET_OVERVIEW_SEARCH = 506
-    ASSET_OVERVIEW_SEARCH_TABS = 507
-    ASSET_OVERVIEW_SEARCH_TAB_CONTENT = 508
-    ASSET_OVERVIEW_RECOVER_PLAYER_VAULT = 509
+    EPIC_ID_HAS_ACTIVE_ACCOUNT = 336
+    LINK_ACCOUNT_TO_EPIC_ID = 337
+    IN_APP_CONFIRM_PAYMENT_GOOGLE_PLAY = 338
+    IN_APP_CONFIRM_PAYMENT_APPLE_APP_STORE = 339
+    IN_APP_PURCHASE_REQUEST = 340
+    IN_APP_PURCHASE_FAILED = 341
+    CHARACTER_SUBSCRIPTION_INFO = 342
+    ACCOUNT_SUBSCRIPTION_INFO = 343
+    BUY_GVG_SEASON_BOOSTER = 344
+    CHANGE_FLAGGING_PREPARE = 345
+    OVER_CHARGE = 346
+    OVER_CHARGE_END = 347
+    REQUEST_TRUSTED = 348
+    CHANGE_GUILD_LOGO = 349
+    PARTY_FINDER_REGISTER_FOR_UPDATES = 350
+    PARTY_FINDER_UNREGISTER_FOR_UPDATES = 351
+    PARTY_FINDER_ENLIST_NEW_PARTY_SEARCH = 352
+    PARTY_FINDER_DELETE_PARTY_SEARCH = 353
+    PARTY_FINDER_CHANGE_PARTY_SEARCH = 354
+    PARTY_FINDER_CHANGE_ROLE = 355
+    PARTY_FINDER_APPLY_FOR_GROUP = 356
+    PARTY_FINDER_ACCEPT_OR_DECLINE_APPLY_FOR_GROUP = 357
+    PARTY_FINDER_GET_EQUIPMENT_SNAPSHOT = 358
+    PARTY_FINDER_REGISTER_APPLICANTS = 359
+    PARTY_FINDER_UNREGISTER_APPLICANTS = 360
+    PARTY_FINDER_FULLTEXT_SEARCH = 361
+    PARTY_FINDER_REQUEST_EQUIPMENT_SNAPSHOT = 362
+    GET_PERSONAL_SEASON_TRACKER_DATA = 363
+    GET_PERSONAL_SEASON_PAST_REWARD_DATA = 364
+    USE_CONSUMABLE_FROM_INVENTORY = 365
+    CLAIM_PERSONAL_SEASON_REWARD = 366
+    XIGN_CODE_MESSAGE_TO_SERVER = 367
+    BATTL_EYE_MESSAGE_TO_SERVER = 368
+    SET_NEXT_TUTORIAL_STATE = 369
+    ADD_PLAYER_TO_MUTE_LIST = 370
+    REMOVE_PLAYER_FROM_MUTE_LIST = 371
+    PRODUCT_SHOP_USER_EVENT = 372
+    GET_VANITY_UNLOCKS = 373
+    BUY_VANITY_UNLOCKS = 374
+    GET_MOUNT_SKINS = 375
+    SET_MOUNT_SKIN = 376
+    SET_WARDROBE = 377
+    CHANGE_CUSTOMIZATION = 378
+    CHANGE_PLAYER_ISLAND_DATA = 379
+    GET_GUILD_CHALLENGE_POINTS = 380
+    SMART_QUEUE_JOIN = 381
+    SMART_QUEUE_LEAVE = 382
+    SMART_QUEUE_SELECT_SPAWN_CLUSTER = 383
+    UPGRADE_HIDEOUT = 384
+    INIT_HIDEOUT_ATTACK_START = 385
+    INIT_HIDEOUT_ATTACK_CANCEL = 386
+    HIDEOUT_FILL_NUTRITION = 387
+    HIDEOUT_GET_INFO = 388
+    HIDEOUT_GET_OWNER_INFO = 389
+    HIDEOUT_SET_TRIBUTE = 390
+    HIDEOUT_UPGRADE_WITH_POWER_CRYSTAL = 391
+    HIDEOUT_DECLARE_H_Q = 392
+    HIDEOUT_UNDECLARE_H_Q = 393
+    HIDEOUT_GET_H_Q_REQUIREMENTS = 394
+    HIDEOUT_BOOST = 395
+    HIDEOUT_BOOST_CONSTRUCTION = 396
+    OPEN_WORLD_ATTACK_SCHEDULE_START = 397
+    OPEN_WORLD_ATTACK_SCHEDULE_CANCEL = 398
+    OPEN_WORLD_ATTACK_CONQUER_START = 399
+    OPEN_WORLD_ATTACK_CONQUER_CANCEL = 400
+    GET_OPEN_WORLD_ATTACK_DETAILS = 401
+    GET_NEXT_OPEN_WORLD_ATTACK_SCHEDULE_TIME = 402
+    RECOVER_VAULT_FROM_HIDEOUT = 403
+    GET_GUILD_ENERGY_DRAIN_INFO = 404
+    CHANNELING_UPDATE = 405
+    USE_CORRUPTED_SHRINE = 406
+    REQUEST_ESTIMATED_MARKET_VALUE = 407
+    LOG_FEEDBACK = 408
+    GET_INFAMY_INFO = 409
+    GET_PARTY_SMART_CLUSTER_QUEUE_PRIORITY = 410
+    SET_PARTY_SMART_CLUSTER_QUEUE_PRIORITY = 411
+    CLIENT_ANTI_AUTO_CLICKER_INFO = 412
+    CLIENT_BOT_PATTERN_DETECTION_INFO = 413
+    CLIENT_ANTI_GATHER_CLICKER_INFO = 414
+    LOADOUT_CREATE = 415
+    LOADOUT_READ = 416
+    LOADOUT_READ_HEADERS = 417
+    LOADOUT_UPDATE = 418
+    LOADOUT_DELETE = 419
+    LOADOUT_ORDER_UPDATE = 420
+    LOADOUT_EQUIP = 421
+    BATCH_USE_ITEM_CANCEL = 422
+    ENLIST_FACTION_WARFARE = 423
+    GET_FACTION_WARFARE_WEEKLY_REPORT = 424
+    CLAIM_FACTION_WARFARE_WEEKLY_REPORT = 425
+    GET_FACTION_WARFARE_CAMPAIGN_DATA = 426
+    CLAIM_FACTION_WARFARE_ITEM_REWARD = 427
+    SEND_MEMORY_CONSUMPTION = 428
+    PICKUP_CARRIABLE_OBJECT_START = 429
+    PICKUP_CARRIABLE_OBJECT_CANCEL = 430
+    SET_SAVING_CHEST_LOGS_FLAG = 431
+    GET_SAVING_CHEST_LOGS_FLAG = 432
+    REGISTER_GUEST_ACCOUNT = 433
+    RESEND_GUEST_ACCOUNT_VERIFICATION_EMAIL = 434
+    DO_SIMPLE_ACTION_START = 435
+    DO_SIMPLE_ACTION_CANCEL = 436
+    GET_GVG_SEASON_CONTRIBUTION_BY_ACTIVITY = 437
+    GET_GVG_SEASON_CONTRIBUTION_BY_CRYSTAL_LEAGUE = 438
+    GET_GUILD_MIGHT_CATEGORY_CONTRIBUTION = 439
+    GET_GUILD_MIGHT_CATEGORY_OVERVIEW = 440
+    GET_PVP_CHALLENGE_DATA = 441
+    CLAIM_PVP_CHALLENGE_WEEKLY_REWARD = 442
+    GET_PERSONAL_MIGHT_STATS = 443
+    GET_PVP_CHALLENGE_SEASON_REWARDS = 444
+    GET_PVP_CHALLENGE_SEASON_REWARD_ITEMS = 445
+    CLAIM_PVP_CHALLENGE_SEASON_REWARDS = 446
+    CLAIM_PVP_CHALLENGE_SEASON_REWARD_ITEMS = 447
+    AUCTION_GET_LOADOUT_OFFERS = 448
+    AUCTION_BUY_LOADOUT_OFFER = 449
+    ACCOUNT_DELETION_REQUEST = 450
+    ACCOUNT_REACTIVATION_REQUEST = 451
+    GET_MODERATION_ESCALATION_DEFINITON = 452
+    EVENT_BASED_POPUP_ADD_SEEN = 453
+    GET_ITEM_KILL_HISTORY = 454
+    GET_VANITY_CONSUMABLES = 455
+    EQUIP_KILL_EMOTE = 456
+    CHANGE_KILL_EMOTE_PLAY_ON_KNOCKDOWN_SETTING = 457
+    BUY_VANITY_CONSUMABLE_CHARGES = 458
+    RECLAIM_VANITY_ITEM = 459
+    GET_ARENA_RANKINGS = 460
+    GET_CRYSTAL_LEAGUE_STATISTICS = 461
+    SEND_OPTIONS_LOG = 462
+    SEND_CONTROLS_OPTIONS_LOG = 463
+    MISTS_USE_IMMEDIATE_RETURN_EXIT = 464
+    MISTS_USE_STATIC_ENTRANCE = 465
+    MISTS_USE_CITY_ROADS_ENTRANCE = 466
+    CHANGE_NEW_GUILD_MEMBER_MAIL = 467
+    GET_NEW_GUILD_MEMBER_MAIL = 468
+    CHANGE_GUILD_FACTION_ALLEGIANCE = 469
+    GET_GUILD_FACTION_ALLEGIANCE = 470
+    GUILD_BANNER_CHANGE = 471
+    GUILD_GET_OPTIONAL_STATS = 472
+    GUILD_SET_OPTIONAL_STATS = 473
+    GET_PLAYER_INFO_FOR_STALK = 474
+    PAY_GOLD_FOR_CHARACTER_TYPE_CHANGE = 475
+    QUICK_SELL_AUCTION_QUERY_ACTION = 476
+    QUICK_SELL_AUCTION_SELL_ACTION = 477
+    FCM_TOKEN_TO_SERVER = 478
+    APNS_TOKEN_TO_SERVER = 479
+    DEATH_RECAP = 480
+    AUCTION_FETCH_FINISHED_AUCTIONS = 481
+    ABORT_AUCTION_FETCH_FINISHED_AUCTIONS = 482
+    REQUEST_LEGENDARY_EVEN_HISTORY = 483
+    PARTY_ANSWER_START_HUNT_REQUEST = 484
+    HUNT_ABORT = 485
+    USE_FIND_TRACK_SPELL_FROM_ITEM_PREPARE = 486
+    INTERACT_WITH_TRACK_START = 487
+    INTERACT_WITH_TRACK_CANCEL = 488
+    TERRITORY_RAID_START = 489
+    TERRITORY_RAID_CANCEL = 490
+    TERRITORY_CLAIM_RAIDED_RAW_ENERGY_CRYSTAL_RESULT = 491
+    GV_G_SEASON_PLAYER_GUILD_PARTICIPATION_DETAILS = 492
+    DAILY_MIGHT_BONUS = 493
+    CLAIM_DAILY_MIGHT_BONUS = 494
+    GET_FORTIFICATION_GROUP_INFO = 495
+    UPGRADE_FORTIFICATION_GROUP = 496
+    CANCEL_UPGRADE_FORTIFICATION_GROUP = 497
+    DOWNGRADE_FORTIFICATION_GROUP = 498
+    GET_CLUSTER_ACTIVITY_CHEST_ESTIMATES = 499
+    PARTY_READY_CHECK_BEGIN = 500
+    PARTY_READY_CHECK_UPDATE = 501
+    CLAIM_ALBION_JOURNAL_REWARD = 502
+    TRACK_ALBION_JOURNAL_ACHIEVEMENTS = 503
+    REQUEST_OUTLANDS_TELEPORTATION_USAGE = 504
+    PICKUP_FROM_PILED_OBJECT_START = 505
+    PICKUP_FROM_PILED_OBJECT_CANCEL = 506
+    ASSET_OVERVIEW = 507
+    ASSET_OVERVIEW_TABS = 508
+    ASSET_OVERVIEW_TAB_CONTENT = 509
+    ASSET_OVERVIEW_UNFREEZE_CACHE = 510
+    ASSET_OVERVIEW_SEARCH = 511
+    ASSET_OVERVIEW_SEARCH_TABS = 512
+    ASSET_OVERVIEW_SEARCH_TAB_CONTENT = 513
+    ASSET_OVERVIEW_RECOVER_PLAYER_VAULT = 514
     IMMORTALIZE_KILL_TROPHY = 51
